linux-kernel.vger.kernel.org archive mirror
 help / color / mirror / Atom feed
* spelling fix
@ 2003-08-18 20:32 Hollis Blanchard
  0 siblings, 0 replies; only message in thread
From: Hollis Blanchard @ 2003-08-18 20:32 UTC (permalink / raw)
  To: Linus Torvalds; +Cc: linux-kernel

Please apply. Especially since this message seems to be popping up a 
lot these days... :)

===== arch/i386/kernel/timers/timer_tsc.c 1.22 vs edited =====
--- 1.22/arch/i386/kernel/timers/timer_tsc.c	Thu Jul  3 19:52:12 2003
+++ edited/arch/i386/kernel/timers/timer_tsc.c	Mon Aug 18 08:46:24 2003
@@ -182,9 +182,9 @@
  	if (lost >= 2) {
  		jiffies += lost-1;

 		/* sanity check to ensure we're not always loosing ticks */
  		if (lost_count++ > 100) {
-			printk(KERN_WARNING "Loosing too many ticks!\n");
+			printk(KERN_WARNING "Losing too many ticks!\n");
  			printk(KERN_WARNING "TSC cannot be used as a timesource."
  					" (Are you running with SpeedStep?)\n");
  			printk(KERN_WARNING "Falling back to a sane timesource.\n");
@@ -182,9 +182,9 @@
  		jiffies += lost-1;

-		/* sanity check to ensure we're not always loosing ticks */
+		/* sanity check to ensure we're not always losing ticks */
  		if (lost_count++ > 100) {

-- 
Hollis Blanchard
IBM Linux Technology Center


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2003-08-18 20:36 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2003-08-18 20:32 spelling fix Hollis Blanchard

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).